/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var mobileAppURL    = 'https://www.iksurfmag.com/mobileapp/?sb=1&inapp=1';
var oneSignalAppID  = '159d8262-4c12-11e5-b354-1f8e200b6b81';
var appIFrameEl     = document.getElementById('mobileApp');

var app = {
    
    // Application Constructor
    initialize: function() {
        document.addEventListener('deviceready', this.onDeviceReady.bind(this), false);
    },

    onDeviceReady: function() {
        
        //so we can use this inside functions
        $this = this;
        
        //stop here if we have no network
        var networkState = this.checkNetworkState();
        if(networkState == 'None')
        {
            this.showAlert('Network Error', 'Sorry this application requires an internet connection.', 'Retry', this.onDeviceReady.bind(this));
            return false;
        }
        
        //add listeners
        document.addEventListener('pause', this.onAppPause.bind(this), false);
        document.addEventListener('resume', this.onAppResume.bind(this), false);
	window.addEventListener('message', this.receiveMessageFromAppIframe.bind(this), false);
        
        //wait until iframe is fully loaded until we do stuff
        appIFrameEl.src = mobileAppURL;
        appIFrameEl.onload = function()
        {
            this.classList.add('loaded');
            $this.onMobileAppLoaded();
        };
        
        //init onesignal
        this.initOneSignal(); 
		
        /*
         *
         * Without this status bar will not overlay even though we speicify in config.xml ???
         *
         */
        if(cordova.platformId == 'android')
        {
            StatusBar.overlaysWebView(true);
            StatusBar.backgroundColorByHexString('#33000000');
        }
		
    },
    
    onMobileAppLoaded: function()
    {
        //do nothing now, 
        //we handle iframe comminication with postMessage due to file:// https:// security errors
    },
            
    onAppPause: function()
    {
        this.sendMessageToAppIframe({type: 'onNativeAppClose'});
    },
            
    onAppResume: function()
    {
        //do nothing for now...
    },
            
    sendMessageToAppIframe: function(data)
    {
        appIFrameEl.contentWindow.postMessage(data, '*');
    },
            
    receiveMessageFromAppIframe: function(event)
    {
        var dataObj = event.data;
        var type    = dataObj.type;
        
        switch(type)
        {
            case 'openShareDialog' :
                this.openShareDialog(dataObj.url, dataObj.title);
                break;
            case 'openInAppBrowser' :
                this.openInAppBrowser(dataObj.url);
                break;
        }
        
    },
          
    openShareDialog: function(url, title)
    {
        //open native share, plugin: cordova-plugin-web-share needed here
        if(navigator.share)
        {
            navigator.share({
                //title: '', //do we need this??
                text: title,
                url: url
            });
        }
        else
        {
            this.showAlert('Error', 'Sorry native share is not available on this device.', 'OK');
        }
    },
    
    openInAppBrowser: function(url)
    {
        //so we can use this inside functions
        $this = this;
        
	//show loader as it seems slow before browser tab shows
        $this.sendMessageToAppIframe({type: 'showIndicator'});
        
        //load the url in the browser tab
        cordova.plugins.browsertab.openUrl(url, null, function()
        {     
            //hide loader on success, we need a timeout here or it hides instantly, strange the browser tab seems slow to appear after a user taps...
            setTimeout(function(){ 
                $this.sendMessageToAppIframe({type: 'hideIndicator'});
            }, 2000);
        });
    },
	
    showAlert: function(title, message, btnText, callback)
    {
	navigator.notification.alert(message, callback, title, btnText);
    },
            
    loadAppPage: function(url)
    {
        //deep link into an app page url format must be mag-articles-slider.html?issue_id=60&slide=4
        this.sendMessageToAppIframe({type: 'loadAppPage', url: url});
    },
            
    showPushNotification: function(jsonData)
    {
        this.sendMessageToAppIframe({type: 'showPushNotification', payload: jsonData});
    },
              
    initOneSignal: function()
    {
        //so we can use this inside the function
        $this = this;
        
        var notificationOpenedCallback = function(jsonData) {
            
            //access the payload object
            var payload = jsonData.notification.payload;
            
            //check here if appIFrame is already loaded or not (app startup)
            if(appIFrameEl.classList.contains('loaded'))
            {
                $this.showPushNotification(payload);
            }
            else //this is an app launch startup so we must wait first
            {
                appIFrameEl.onload = function()
                {
                    $this.showPushNotification(payload);
                };
            }
        };

        window.plugins.OneSignal
                .startInit(oneSignalAppID)
                .handleNotificationOpened(notificationOpenedCallback)
                .inFocusDisplaying(window.plugins.OneSignal.OSInFocusDisplayOption.Notification)
                .endInit();
    },
            
    checkNetworkState: function()
    {
        var networkState = navigator.connection.type;

        var states = {};
        states[Connection.ETHERNET] = 'Ethernet connection';
        states[Connection.WIFI]     = 'WiFi connection';
        states[Connection.CELL_2G]  = 'Cell 2G connection';
        states[Connection.CELL_3G]  = 'Cell 3G connection';
        states[Connection.CELL_4G]  = 'Cell 4G connection';
        states[Connection.CELL]     = 'Cell generic connection';
        states[Connection.NONE]     = 'None';
        states[Connection.UNKNOWN]  = 'Unkown';

        return states[networkState];
    }
};

//init the app
app.initialize();

/*
 * 
 * This function is called when a custom url scheme is used to open the app from the cordova-plugin-customurlscheme plugin
 * It must be called handleOpenURL(url)
 * Bit annoying it is outside the scope of the app above.
 * 
 */
function handleOpenURL(url)
{
    
    /*
     * FB iOS app link data looks like
     * iksurfmag://mag|issue_id:49?al_applink_data=JSON_ENCODED_DATA
     */
				
    /*
     * FB Android app link data looks like
     * iksurfmag://mag|issue_id:49?target_url=
     */
    
    /*
     * 
     * Normal app link look like iksurfmag://mag|issue_id:49
     * 
     */
    
    //when an article link is clicked from the facebook app it will have either al_applink_data= for iOS or target_url= for Android in it
    if(url.indexOf('al_applink_data=') > -1 || url.indexOf('target_url=') > -1)
    {
        //we need to grab eveything from before the ? to clean up the url
        url = url.split('?')[0];
    }
    
    //now format into an appurl that will load
    var appURL = formatAppLinkToAppURL(url);
    
    //check here if iFrame is already loaded or not (app startup)
    if(appIFrameEl.classList.contains('loaded'))
    {
        app.loadAppPage(appURL);
    }
    else //this is an app launch startup so we must wait first
    {
        appIFrameEl.onload = function()
        {
            app.loadAppPage(appURL);
        };
    }
}


/*
 * 
 * Format App Link to URL
 * 
 */
function formatAppLinkToAppURL(url)
{
    //now get the part after uri_scheme:// only
    url = url.substr(url.indexOf('://') + 3);
    
    //now do some string manipulation to create mag|issue_id:49 into mag.html?issue_id=49
    url = url.replace('|', '.html?'); //facebook passes this like normal... hmm think of a better character alex
    url = url.replace('%7C', '.html?'); //for some reason | is passed in as %7C bit dogey here from chrome browsers... *fix*
    url = url.replace(':', '=');
    url	= url.replace('/', '&');
    
    return url;
}